@@ -1,5 +1,5 @@
 /***************************************************************************
-    copyright            : (C) 2003-2005 by Robby Stephenson
+    copyright            : (C) 2003-2006 by Robby Stephenson
     email                : robby@periapsis.org
  ***************************************************************************/
 
@@ -19,16 +19,15 @@
 #include "tellico_kernel.h"
 #include "translators/tellico_xml.h"
 #include "tellico_utils.h"
+#include "tellico_debug.h"
 
 #include <klocale.h>
 #include <kcombobox.h>
 #include <klineedit.h>
-#include <kdebug.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
 #include <kpushbutton.h>
 #include <kaccelmanager.h>
-#include <kdeversion.h>
 
 #include <qgroupbox.h>
 #include <qlayout.h>
@@ -40,50 +39,20 @@
 #include <qcheckbox.h>
 #include <qregexp.h>
 #include <qwhatsthis.h>
-#include <qpainter.h>
 #include <qtimer.h>
 
-using Tellico::ListBoxText;
+using Tellico::FieldListBox;
 using Tellico::CollectionFieldsDialog;
 
-ListBoxText::ListBoxText(QListBox* listbox_, Data::Field* field_)
-    : QListBoxText(listbox_, field_->title()), m_field(field_), m_colored(false) {
+FieldListBox::FieldListBox(QListBox* listbox_, Data::FieldPtr field_)
+    : GUI::ListBoxText(listbox_, field_->title()), m_field(field_) {
 }
 
-ListBoxText::ListBoxText(QListBox* listbox_, Data::Field* field_, QListBoxItem* after_)
-    : QListBoxText(listbox_, field_->title(), after_), m_field(field_), m_colored(false) {
+FieldListBox::FieldListBox(QListBox* listbox_, Data::FieldPtr field_, QListBoxItem* after_)
+    : GUI::ListBoxText(listbox_, field_->title(), after_), m_field(field_) {
 }
 
-void ListBoxText::setColored(bool colored_) {
-  if(m_colored != colored_) {
-    m_colored = colored_;
-    listBox()->triggerUpdate(false);
-  }
-}
-
-void ListBoxText::setText(const QString& text_) {
-  QListBoxText::setText(text_);
-  listBox()->triggerUpdate(true);
-}
-
-// mostly copied from QListBoxText::paint() in Qt 3.1.1
-void ListBoxText::paint(QPainter* painter_) {
-  int itemHeight = height(listBox());
-  QFontMetrics fm = painter_->fontMetrics();
-  int yPos = ((itemHeight - fm.height()) / 2) + fm.ascent();
-  if(m_colored) {
-    QFont font = painter_->font();
-    font.setBold(true);
-    font.setItalic(true);
-    painter_->setFont(font);
-    if(!isSelected()) {
-      painter_->setPen(listBox()->colorGroup().highlight());
-    }
-  }
-  painter_->drawText(3, yPos, text());
-}
-
-CollectionFieldsDialog::CollectionFieldsDialog(Data::Collection* coll_, QWidget* parent_, const char* name_/*=0*/)
+CollectionFieldsDialog::CollectionFieldsDialog(Data::CollPtr coll_, QWidget* parent_, const char* name_/*=0*/)
     : KDialogBase(parent_, name_, false, i18n("Collection Fields"), Help|Default|Ok|Apply|Cancel, Ok, false),
       m_coll(coll_),
       m_defaultCollection(0),
@@ -105,7 +74,7 @@ CollectionFieldsDialog::CollectionFieldsDialog(Data::Collection* coll_, QWidget*
   for(Data::FieldVec::Iterator it = fields.begin(); it != fields.end(); ++it) {
     // ignore ReadOnly
     if(it->type() != Data::Field::ReadOnly) {
-      (void) new ListBoxText(m_fieldsBox, it);
+      (void) new FieldListBox(m_fieldsBox, it);
     }
   }
   connect(m_fieldsBox, SIGNAL(highlighted(int)), SLOT(slotHighlightedChanged(int)));
@@ -146,10 +115,11 @@ CollectionFieldsDialog::CollectionFieldsDialog(Data::Collection* coll_, QWidget*
   // (parent, nrows, ncols, margin, spacing)
   QGridLayout* layout = new QGridLayout(grid, 4, 4, 0, KDialog::spacingHint());
 
+  int row = -1;
   QLabel* label = new QLabel(i18n("&Title:"), grid);
-  layout->addWidget(label, 0, 0);
+  layout->addWidget(label, ++row, 0);
   m_titleEdit = new KLineEdit(grid);
-  layout->addWidget(m_titleEdit, 0, 1);
+  layout->addWidget(m_titleEdit, row, 1);
   label->setBuddy(m_titleEdit);
   QString whats = i18n("The title of the field");
   QWhatsThis::add(label, whats);
@@ -157,9 +127,9 @@ CollectionFieldsDialog::CollectionFieldsDialog(Data::Collection* coll_, QWidget*
   connect(m_titleEdit, SIGNAL(textChanged(const QString&)), SLOT(slotModified()));
 
   label = new QLabel(i18n("T&ype:"), grid);
-  layout->addWidget(label, 0, 2);
+  layout->addWidget(label, row, 2);
   m_typeCombo = new KComboBox(grid);
-  layout->addWidget(m_typeCombo, 0, 3);
+  layout->addWidget(m_typeCombo, row, 3);
   label->setBuddy(m_typeCombo);
   whats = QString::fromLatin1("<qt>");
   whats += i18n("The type of the field determines what values may be used. ");
@@ -185,9 +155,9 @@ CollectionFieldsDialog::CollectionFieldsDialog(Data::Collection* coll_, QWidget*
   connect(m_typeCombo, SIGNAL(activated(const QString&)), SLOT(slotTypeChanged(const QString&)));
 
   label = new QLabel(i18n("Cate&gory:"), grid);
-  layout->addWidget(label, 1, 0);
+  layout->addWidget(label, ++row, 0);
   m_catCombo = new KComboBox(true, grid);
-  layout->addWidget(m_catCombo, 1, 1);
+  layout->addWidget(m_catCombo, row, 1);
   label->setBuddy(m_catCombo);
   whats = i18n("The field category determines where the field is placed in the editor.");
   QWhatsThis::add(label, whats);
@@ -207,10 +177,10 @@ CollectionFieldsDialog::CollectionFieldsDialog(Data::Collection* coll_, QWidget*
   connect(m_catCombo, SIGNAL(textChanged(const QString&)), SLOT(slotModified()));
 
   label = new QLabel(i18n("Descr&iption:"), grid);
-  layout->addWidget(label, 2, 0);
+  layout->addWidget(label, ++row, 0);
   m_descEdit = new KLineEdit(grid);
   m_descEdit->setMinimumWidth(150);
-  layout->addMultiCellWidget(m_descEdit, 2, 2, 1, 3);
+  layout->addMultiCellWidget(m_descEdit, row, row, 1, 3);
   label->setBuddy(m_descEdit);
   whats = i18n("The description is a useful reminder of what information is contained in the "
                "field. For <i>Dependent</i> fields, the description is a format string such as "
@@ -219,22 +189,33 @@ CollectionFieldsDialog::CollectionFieldsDialog(Data::Collection* coll_, QWidget*
   QWhatsThis::add(m_descEdit, whats);
   connect(m_descEdit, SIGNAL(textChanged(const QString&)), SLOT(slotModified()));
 
-  label = new QLabel(i18n("A&llowed:"), grid);
-  layout->addWidget(label, 3, 0);
+  label = new QLabel(i18n("&Default value:"), grid);
+  layout->addWidget(label, ++row, 0);
+  m_defaultEdit = new KLineEdit(grid);
+  layout->addMultiCellWidget(m_defaultEdit, row, row, 1, 3);
+  label->setBuddy(m_defaultEdit);
+  whats = i18n("<qt>A default value can be set for new entries.</qt>");
+  QWhatsThis::add(label, whats);
+  QWhatsThis::add(m_defaultEdit, whats);
+  connect(m_defaultEdit, SIGNAL(textChanged(const QString&)), SLOT(slotModified()));
+
+  label = new QLabel(i18n("A&llowed values:"), grid);
+  layout->addWidget(label, ++row, 0);
   m_allowEdit = new KLineEdit(grid);
-  layout->addMultiCellWidget(m_allowEdit, 3, 3, 1, 3);
+  layout->addMultiCellWidget(m_allowEdit, row, row, 1, 3);
   label->setBuddy(m_allowEdit);
   whats = i18n("<qt>For <i>Choice</i>-type fields, these are the only values allowed. They are "
-               "placed in a combo box.</qt>");
+               "placed in a combo box. The possible value have to be seperated by a semi-colon, "
+               "for example: \"dog; cat; mouse\"</qt>");
   QWhatsThis::add(label, whats);
   QWhatsThis::add(m_allowEdit, whats);
   connect(m_allowEdit, SIGNAL(textChanged(const QString&)), SLOT(slotModified()));
 
   label = new QLabel(i18n("Extended &properties:"), grid);
-  layout->addWidget(label, 4, 0);
+  layout->addWidget(label, ++row, 0);
   m_btnExtended = new KPushButton(i18n("&Set..."), grid);
   m_btnExtended->setIconSet(BarIcon(QString::fromLatin1("bookmark"), KIcon::SizeSmall));
-  layout->addMultiCellWidget(m_btnExtended, 4, 4, 1, 1);
+  layout->addWidget(m_btnExtended, row, 1);
   label->setBuddy(m_btnExtended);
   whats = i18n("Extended field properties are used to specify things such as the corresponding bibtex field.");
   QWhatsThis::add(label, whats);
@@ -272,9 +253,7 @@ CollectionFieldsDialog::CollectionFieldsDialog(Data::Collection* coll_, QWidget*
 
   // need to stretch at bottom
   vbox->setStretchFactor(new QWidget(vbox), 1);
-#if KDE_IS_VERSION(3,1,90)
   KAcceleratorManager::manage(vbox);
-#endif
 
   // keep a default collection
   m_defaultCollection = CollectionFactory::collection(m_coll->type(), true);
@@ -343,7 +322,7 @@ void CollectionFieldsDialog::slotApply() {
           if(field->type() == Data::Field::Choice) {
             field->setAllowed(oldValues);
           } else { // rating field
-            Data::Field* oldField = m_coll->fieldByName(field->name());
+            Data::FieldPtr oldField = m_coll->fieldByName(field->name());
             field->setProperty(QString::fromLatin1("minimum"), oldField->property(QString::fromLatin1("minimum")));
             field->setProperty(QString::fromLatin1("maximum"), oldField->property(QString::fromLatin1("maximum")));
           }
@@ -361,9 +340,9 @@ void CollectionFieldsDialog::slotApply() {
   // set all text not to be colored, and get new list
   Data::FieldVec fields;
   for(QListBoxItem* item = m_fieldsBox->firstItem(); item; item = item->next()) {
-    static_cast<ListBoxText*>(item)->setColored(false);
+    static_cast<FieldListBox*>(item)->setColored(false);
     if(m_reordered) {
-      Data::Field* field = static_cast<ListBoxText*>(item)->field();
+      Data::FieldPtr field = static_cast<FieldListBox*>(item)->field();
       if(field) {
         fields.append(field);
       }
@@ -418,12 +397,12 @@ void CollectionFieldsDialog::slotNew() {
     title = i18n("New Field") + QString::fromLatin1(" %1").arg(count);
   }
 
-  Data::Field* field = new Data::Field(name, title);
+  Data::FieldPtr field = new Data::Field(name, title);
   m_newFields.append(field);
-//  kdDebug() << "CollectionFieldsDialog::slotNew() - adding new field " << title << endl;
+//  myDebug() << "CollectionFieldsDialog::slotNew() - adding new field " << title << endl;
 
 //  m_fieldsBox->insertItem(title);
-  ListBoxText* box = new ListBoxText(m_fieldsBox, field);
+  FieldListBox* box = new FieldListBox(m_fieldsBox, field);
   m_fieldsBox->setSelected(box, true);
   box->setColored(true);
   m_fieldsBox->ensureCurrentVisible();
@@ -500,7 +479,7 @@ void CollectionFieldsDialog::slotTypeChanged(const QString& type_) {
 }
 
 void CollectionFieldsDialog::slotHighlightedChanged(int index_) {
-//  kdDebug() << "CollectionFieldsDialog::slotHighlightedChanged() - " << index_ << endl;
+//  myDebug() << "CollectionFieldsDialog::slotHighlightedChanged() - " << index_ << endl;
 
   // use this instead of blocking signals everywhere
   m_updatingValues = true;
@@ -521,7 +500,7 @@ void CollectionFieldsDialog::slotHighlightedChanged(int index_) {
   m_btnUp->setEnabled(index_ > 0);
   m_btnDown->setEnabled(index_ < static_cast<int>(m_fieldsBox->count())-1);
 
-  ListBoxText* item = dynamic_cast<ListBoxText*>(m_fieldsBox->item(index_));
+  FieldListBox* item = dynamic_cast<FieldListBox*>(m_fieldsBox->item(index_));
   if(!item) {
     return;
   }
@@ -529,7 +508,7 @@ void CollectionFieldsDialog::slotHighlightedChanged(int index_) {
   // need to get a pointer to the field with the new values to insert
   Data::FieldPtr field = item->field();
   if(!field) {
-    kdDebug() << "CollectionFieldsDialog::slotHighlightedChanged() - no field found!" << endl;
+    myDebug() << "CollectionFieldsDialog::slotHighlightedChanged() - no field found!" << endl;
     return;
   }
 
@@ -555,9 +534,11 @@ void CollectionFieldsDialog::slotHighlightedChanged(int index_) {
 
   m_catCombo->setCurrentText(field->category()); // have to do this here
   m_descEdit->setText(field->description());
+  m_defaultEdit->setText(field->defaultValue());
 
   switch(field->formatFlag()) {
     case Data::Field::FormatNone:
+    case Data::Field::FormatDate: // as yet unimplemented
       m_formatNone->setChecked(true);
       break;
 
@@ -574,6 +555,7 @@ void CollectionFieldsDialog::slotHighlightedChanged(int index_) {
       break;
 
     default:
+      kdWarning() << "CollectionFieldsDialog::slotHighlightedChanged() - no format type!" << endl;
       break;
   }
 
@@ -586,7 +568,7 @@ void CollectionFieldsDialog::slotHighlightedChanged(int index_) {
 
   // default button is enabled only if default collection contains the field
   if(m_defaultCollection) {
-    bool hasField = (m_defaultCollection->fieldByName(field->name()) != 0);
+    bool hasField = m_defaultCollection->hasField(field->name());
     actionButton(KDialogBase::Default)->setEnabled(hasField);
   }
 
@@ -595,8 +577,8 @@ void CollectionFieldsDialog::slotHighlightedChanged(int index_) {
 }
 
 void CollectionFieldsDialog::updateField() {
-//  kdDebug() << "CollectionFieldsDialog::updateField()" << endl;
-  Data::Field* field = m_currentField;
+//  myDebug() << "CollectionFieldsDialog::updateField()" << endl;
+  Data::FieldPtr field = m_currentField;
   if(!field || !m_modified) {
     return;
   }
@@ -608,7 +590,7 @@ void CollectionFieldsDialog::updateField() {
     if(name.isEmpty()) { // might end up with empty string
       name = QString::fromLatin1("custom") + QString::number(m_newFields.count()+1);
     }
-    while(m_coll->fieldByName(name)) { // ensure name uniqueness
+    while(m_coll->hasField(name)) { // ensure name uniqueness
       name += QString::fromLatin1("-new");
     }
     field->setName(name);
@@ -650,6 +632,7 @@ void CollectionFieldsDialog::updateField() {
   }
 
   field->setDescription(m_descEdit->text());
+  field->setDefaultValue(m_defaultEdit->text());
 
   if(m_formatTitle->isChecked()) {
     field->setFormatFlag(Data::Field::FormatTitle);
@@ -679,7 +662,7 @@ void CollectionFieldsDialog::updateField() {
 // The purpose here is to first set the modified flag. Then, if the field being edited is one
 // that exists in the collection already, a deep copy needs to be made.
 void CollectionFieldsDialog::slotModified() {
-//  kdDebug() << "CollectionFieldsDialog::slotModified()" << endl;
+//  myDebug() << "CollectionFieldsDialog::slotModified()" << endl;
   // if I'm just updating the values, I don't care
   if(m_updatingValues) {
     return;
@@ -691,12 +674,12 @@ void CollectionFieldsDialog::slotModified() {
   enableButtonApply(true);
 
   if(!m_currentField) {
-    kdDebug() << "CollectionFieldsDialog::slotModified() - no current field!" << endl;
-    m_currentField = static_cast<ListBoxText*>(m_fieldsBox->selectedItem())->field();
+    myDebug() << "CollectionFieldsDialog::slotModified() - no current field!" << endl;
+    m_currentField = static_cast<FieldListBox*>(m_fieldsBox->selectedItem())->field();
   }
 
   // color the text
-  static_cast<ListBoxText*>(m_fieldsBox->selectedItem())->setColored(true);
+  static_cast<FieldListBox*>(m_fieldsBox->selectedItem())->setColored(true);
 
   // check if copy exists already
   if(m_copiedFields.contains(m_currentField)) {
@@ -709,18 +692,16 @@ void CollectionFieldsDialog::slotModified() {
     return;
   }
 
-  Data::Field* newField = m_currentField->clone();
-
-  m_copiedFields.append(newField);
-  m_currentField = newField;
-  static_cast<ListBoxText*>(m_fieldsBox->selectedItem())->setField(newField);
+  m_currentField = new Data::Field(*m_currentField);
+  m_copiedFields.append(m_currentField);
+  static_cast<FieldListBox*>(m_fieldsBox->selectedItem())->setField(m_currentField);
 }
 
 void CollectionFieldsDialog::slotUpdateTitle(const QString& title_) {
-//  kdDebug() << "CollectionFieldsDialog::slotUpdateTitle()" << endl;
+//  myDebug() << "CollectionFieldsDialog::slotUpdateTitle()" << endl;
   if(m_currentField && m_currentField->title() != title_) {
     m_fieldsBox->blockSignals(true);
-    ListBoxText* oldItem = findItem(m_fieldsBox, m_currentField);
+    FieldListBox* oldItem = findItem(m_fieldsBox, m_currentField);
     if(!oldItem) {
       return;
     }
@@ -739,7 +720,7 @@ void CollectionFieldsDialog::slotDefault() {
     return;
   }
 
-  Data::Field* defaultField = m_defaultCollection->fieldByName(m_currentField->name());
+  Data::FieldPtr defaultField = m_defaultCollection->fieldByName(m_currentField->name());
   if(!defaultField) {
     return;
   }
@@ -769,10 +750,11 @@ void CollectionFieldsDialog::slotDefault() {
 
   m_catCombo->setCurrentText(defaultField->category()); // have to do this here
   m_descEdit->setText(defaultField->description());
-//  m_bibtexEdit->setText(defaultField->property(QString::fromLatin1("bibtex")));
+  m_defaultEdit->setText(defaultField->defaultValue());
 
   switch(defaultField->formatFlag()) {
     case Data::Field::FormatNone:
+    case Data::Field::FormatDate:
       m_formatNone->setChecked(true);
       break;
 
@@ -799,24 +781,19 @@ void CollectionFieldsDialog::slotDefault() {
 
   m_btnDelete->setEnabled(!(defaultField->flags() & Data::Field::NoDelete));
 
-  // type is only changeable for new attributes
-  m_typeCombo->setEnabled(false);
-
 //  m_titleEdit->setFocus();
 //  m_titleEdit->selectAll();
 
   m_updatingValues = false;
-
   slotModified();
 }
 
 void CollectionFieldsDialog::slotMoveUp() {
-  QListBoxItem* item;
-  item = m_fieldsBox->selectedItem();
+  QListBoxItem* item = m_fieldsBox->selectedItem();
   if(item) {
-    ListBoxText* prev = dynamic_cast<ListBoxText*>(item->prev()); // could be 0
+    FieldListBox* prev = static_cast<FieldListBox*>(item->prev()); // could be 0
     if(prev) {
-      (void) new ListBoxText(m_fieldsBox, prev->field(), item);
+      (void) new FieldListBox(m_fieldsBox, prev->field(), item);
       delete prev;
       m_fieldsBox->ensureCurrentVisible();
       // since the current one doesn't get re-highlighted, need to highlighted doesn't get emitted
@@ -832,11 +809,11 @@ void CollectionFieldsDialog::slotMoveUp() {
 }
 
 void CollectionFieldsDialog::slotMoveDown() {
-  ListBoxText* item = dynamic_cast<ListBoxText*>(m_fieldsBox->selectedItem());
+  FieldListBox* item = dynamic_cast<FieldListBox*>(m_fieldsBox->selectedItem());
   if(item) {
     QListBoxItem* next = item->next(); // could be 0
     if(next) {
-      QListBoxItem* newItem = new ListBoxText(m_fieldsBox, item->field(), next);
+      QListBoxItem* newItem = new FieldListBox(m_fieldsBox, item->field(), next);
       delete item;
       m_fieldsBox->setSelected(newItem, true);
       m_fieldsBox->ensureCurrentVisible();
@@ -850,10 +827,10 @@ void CollectionFieldsDialog::slotMoveDown() {
   enableButtonApply(true);
 }
 
-ListBoxText* CollectionFieldsDialog::findItem(const QListBox* box_, const Data::Field* field_) {
-//  kdDebug() << "CollectionFieldsDialog::findItem()" << endl;
+Tellico::FieldListBox* CollectionFieldsDialog::findItem(const QListBox* box_, Data::FieldPtr field_) {
+//  myDebug() << "CollectionFieldsDialog::findItem()" << endl;
   for(QListBoxItem* item = box_->firstItem(); item; item = item->next()) {
-    ListBoxText* textItem = static_cast<ListBoxText*>(item);
+    FieldListBox* textItem = static_cast<FieldListBox*>(item);
     if(textItem->field() == field_) {
       return textItem;
     }
@@ -866,16 +843,24 @@ bool CollectionFieldsDialog::slotShowExtendedProperties() {
     return false;
   }
 
-  StringMapDialog* dlg = new StringMapDialog(m_currentField->propertyList(), this, "ExtendedPropertiesDialog", true);
-  dlg->setCaption(i18n("Extended Field Properties"));
-  dlg->setLabels(i18n("Property"), i18n("Value"));
-  if(dlg->exec() == QDialog::Accepted) {
-    m_currentField->setPropertyList(dlg->stringMap());
-    dlg->delayedDestruct();
+  // the default value is included in properties, but it has a
+  // separate edit box
+  QString dv = m_currentField->defaultValue();
+  StringMap props = m_currentField->propertyList();
+  props.remove(QString::fromLatin1("default"));
+
+  StringMapDialog dlg(props, this, "ExtendedPropertiesDialog", true);
+  dlg.setCaption(i18n("Extended Field Properties"));
+  dlg.setLabels(i18n("Property"), i18n("Value"));
+  if(dlg.exec() == QDialog::Accepted) {
+    props = dlg.stringMap();
+    if(!dv.isEmpty()) {
+      props.insert(QString::fromLatin1("default"), dv);
+    }
+    m_currentField->setPropertyList(props);
     slotModified();
     return true;
   }
-  dlg->delayedDestruct();
   return false;
 }
 
@@ -936,9 +921,9 @@ bool CollectionFieldsDialog::checkValues() {
     bool ok; // ok to ignore this here
     int ncols = Tellico::toUInt(m_currentField->property(QString::fromLatin1("columns")), &ok);
     // also enforced in GUI::TableFieldWidget
-    if(ncols > 5) {
-      KMessageBox::sorry(this, i18n("Tables are limited to a maximum of five columns."));
-      m_currentField->setProperty(QString::fromLatin1("columns"), QChar('5'));
+    if(ncols > 10) {
+      KMessageBox::sorry(this, i18n("Tables are limited to a maximum of ten columns."));
+      m_currentField->setProperty(QString::fromLatin1("columns"), QString::fromLatin1("10"));
     }
   }
 
@@ -1014,7 +999,7 @@ QStringList CollectionFieldsDialog::newTypesAllowed(int type_ /*=0*/) {
       break;
 
     default:
-      kdDebug() << "CollectionFieldsDialog::newTypesAllowed() - no match for " << type_ << endl;
+      myDebug() << "CollectionFieldsDialog::newTypesAllowed() - no match for " << type_ << endl;
       newTypes = Data::Field::typeTitles();
       break;
   }
