@@ -1,5 +1,5 @@
 /***************************************************************************
-    copyright            : (C) 2005 by Robby Stephenson
+    copyright            : (C) 2005-2006 by Robby Stephenson
     email                : robby@periapsis.org
  ***************************************************************************/
 
@@ -14,13 +14,10 @@
 #ifndef TELLICO_REORDERFIELDS_H
 #define TELLICO_REORDERFIELDS_H
 
-#include "../collection.h"
 #include "../datavectors.h"
 
 #include <kcommand.h>
 
-#include <qguardedptr.h>
-
 namespace Tellico {
   namespace Command {
 
@@ -30,14 +27,14 @@ namespace Tellico {
 class ReorderFields : public KCommand {
 
 public:
-  ReorderFields(Data::Collection* coll, const Data::FieldVec& oldFields, const Data::FieldVec& newFields);
+  ReorderFields(Data::CollPtr coll, const Data::FieldVec& oldFields, const Data::FieldVec& newFields);
 
   virtual void execute();
   virtual void unexecute();
   virtual QString name() const;
 
 private:
-  QGuardedPtr<Data::Collection> m_coll;
+  Data::CollPtr m_coll;
   Data::FieldVec m_oldFields;
   Data::FieldVec m_newFields;
 };
