@@ -37,6 +37,29 @@ EntryGroup::~EntryGroup() {
   }
 }
 
+bool Entry::operator==(const Entry& e1) {
+// special case for file catalog, just check the url
+  if(m_coll && m_coll->type() == Collection::File &&
+     e1.m_coll && e1.m_coll->type() == Collection::File) {
+    // don't forget case where both could have empty urls
+    // but different values for other fields
+    QString u = field(QString::fromLatin1("url"));
+    if(!u.isEmpty()) {
+      // versions before 1.2.7 could have saved the url without the protocol
+      return KURL::fromPathOrURL(u) == KURL::fromPathOrURL(e1.field(QString::fromLatin1("url")));
+    }
+  }
+  if(e1.m_fields.count() != m_fields.count()) {
+    return false;
+  }
+  for(StringMap::ConstIterator it = e1.m_fields.begin(); it != e1.m_fields.end(); ++it) {
+    if(!m_fields.contains(it.key()) || m_fields[it.key()] != it.data()) {
+      return false;
+    }
+  }
+  return true;
+}
+
 Entry::Entry(CollPtr coll_) : KShared(), m_coll(coll_), m_id(-1) {
 #ifndef NDEBUG
   if(!coll_) {
@@ -367,16 +390,24 @@ int Entry::compareValues(EntryPtr e1, EntryPtr e2, FieldPtr f) {
       return 5;
     }
   }
+  // try removing puctuation
+  QRegExp notAlphaNum(QString::fromLatin1("[^\\s\\w]"));
+  QString s1a = s1; s1a.remove(notAlphaNum);
+  QString s2a = s2; s2a.remove(notAlphaNum);
+  if(!s1a.isEmpty() && s1a == s2a) {
+//    myDebug() << "match without punctuation" << endl;
+    return 5;
+  }
   Field::stripArticles(s1);
   Field::stripArticles(s2);
-  if(s1 == s2) {
+  if(!s1.isEmpty() && s1 == s2) {
 //    myDebug() << "match without articles" << endl;
     return 3;
   }
   QRegExp rx(QString::fromLatin1("\\s*\\(.*\\)\\s*"));
   s1.remove(rx);
   s2.remove(rx);
-  if(s1 == s2) {
+  if(!s1.isEmpty() && s1 == s2) {
 //    myDebug() << "match without parentheses" << endl;
     return 1;
   }
