@@ -1,5 +1,5 @@
 /***************************************************************************
-    copyright            : (C) 2003-2005 by Robby Stephenson
+    copyright            : (C) 2003-2006 by Robby Stephenson
     email                : robby@periapsis.org
  ***************************************************************************/
 
@@ -16,6 +16,9 @@
 
 #include "filterdialog.h"
 #include "tellico_kernel.h"
+#include "document.h"
+#include "collection.h"
+#include "fieldcompletion.h"
 
 #include <klocale.h>
 #include <kdebug.h>
@@ -76,6 +79,8 @@ void FilterRuleWidget::initWidget() {
 
   m_ruleField = new KComboBox(this);
   connect(m_ruleField, SIGNAL(activated(int)), SIGNAL(signalModified()));
+  connect(m_ruleField, SIGNAL(activated(int)), SLOT(slotRuleFieldChanged(int)));
+
   m_ruleFunc = new KComboBox(this);
   connect(m_ruleFunc, SIGNAL(activated(int)), SIGNAL(signalModified()));
   m_ruleValue = new KLineEdit(this);
@@ -117,6 +122,25 @@ void FilterRuleWidget::slotEditRegExp() {
   }
 }
 
+void FilterRuleWidget::slotRuleFieldChanged(int which_) {
+  Q_UNUSED(which_);
+  QString fieldTitle = m_ruleField->currentText();
+  if(fieldTitle.isEmpty() || fieldTitle[0] == '<') {
+    m_ruleValue->setCompletionObject(0);
+    return;
+  }
+  Data::FieldPtr field = Data::Document::self()->collection()->fieldByTitle(fieldTitle);
+  if(field && (field->flags() & Data::Field::AllowCompletion)) {
+    FieldCompletion* completion = new FieldCompletion(field->flags() & Data::Field::AllowMultiple);
+    completion->setItems(Kernel::self()->valuesByFieldName(field->name()));
+    completion->setIgnoreCase(true);
+    m_ruleValue->setCompletionObject(completion);
+    m_ruleValue->setAutoDeleteCompletionObject(true);
+  } else {
+    m_ruleValue->setCompletionObject(0);
+  }
+}
+
 void FilterRuleWidget::slotRuleFunctionChanged(int which_) {
   // The 5th and 6th functions are for regexps
   m_editRegExp->setEnabled(which_ == 4 || which_ == 5);
@@ -179,7 +203,7 @@ void FilterRuleWidget::setFocus() {
 /***************************************************************/
 
 namespace {
-  static const int FILTER_MIN_RULE_WIDGETS = 2;
+  static const int FILTER_MIN_RULE_WIDGETS = 1;
   static const int FILTER_MAX_RULES = 8;
 }
 
@@ -188,7 +212,7 @@ FilterRuleWidgetLister::FilterRuleWidgetLister(QWidget* parent_, const char* nam
 //  slotClear();
 }
 
-void FilterRuleWidgetLister::setFilter(const Filter* filter_) {
+void FilterRuleWidgetLister::setFilter(Filter::Ptr filter_) {
 //  if(mWidgetList.first()) { // move this below next 'if'?
 //    mWidgetList.first()->blockSignals(true);
 //  }
@@ -305,7 +329,7 @@ void FilterDialog::init() {
   setHelp(QString::fromLatin1("filter-dialog"));
 }
 
-Tellico::Filter* FilterDialog::currentFilter() {
+Tellico::FilterPtr FilterDialog::currentFilter() {
   if(!m_filter) {
     m_filter = new Filter(Filter::MatchAny);
   }
@@ -331,7 +355,7 @@ Tellico::Filter* FilterDialog::currentFilter() {
   return m_filter;
 }
 
-void FilterDialog::setFilter(Filter* filter_) {
+void FilterDialog::setFilter(FilterPtr filter_) {
   if(!filter_) {
     slotClear();
     return;
@@ -389,7 +413,7 @@ void FilterDialog::slotSaveFilter() {
   // in this case, currentFilter() either creates a new filter or
   // updates the current one. If creating a new one, then I want to copy it
   bool wasEmpty = (m_filter == 0);
-  Tellico::Filter* filter = new Filter(*currentFilter());
+  FilterPtr filter = new Filter(*currentFilter());
   if(wasEmpty) {
     m_filter = filter;
   }
