@@ -123,9 +123,10 @@ public:
   static QPixmap pixmap(const QString& id, int w, int h);
 
   /**
-   * Clean the temp dir and remove all temporary image files
+   * Clear the image cache and dict
+   * if deleteTempDirectory = true, then clean the temp dir and remove all temporary image files
    */
-  static void clean();
+  static void clean(bool deleteTempDirectory);
   /**
    * Creates the gradient images used in the entry view.
    */
@@ -168,6 +169,7 @@ private:
 
   static const Data::Image& addCachedImageImpl(const QString& id, CacheDir dir);
   static bool hasImage(const QString& id);
+  static void releaseImages();
 
   static bool s_needInit;
   static QDict<Data::Image> s_imageDict;
@@ -175,6 +177,7 @@ private:
   static QCache<QPixmap> s_pixmapCache;
   static QMap<QString, Data::ImageInfo> s_imageInfoMap;
   static StringSet s_imagesInTmpDir; // the id's of the images written to tmp directory
+  static StringSet s_imagesToRelease;
   static KTempDir* s_tmpDir;
   static const Data::Image s_null;
 };
