@@ -1,5 +1,5 @@
 /***************************************************************************
-    copyright            : (C) 2003-2005 by Robby Stephenson
+    copyright            : (C) 2003-2006 by Robby Stephenson
     email                : robby@periapsis.org
  ***************************************************************************/
 
@@ -29,26 +29,25 @@
 #include "commands/filtercommand.h"
 #include "commands/addentries.h"
 #include "commands/modifyentries.h"
+#include "commands/updateentries.h"
 #include "commands/removeentries.h"
 #include "commands/removeloans.h"
 #include "commands/reorderfields.h"
 #include "commands/renamecollection.h"
+#include "collectionfactory.h"
+#include "stringset.h"
 
-#include <kdebug.h>
 #include <kmessagebox.h>
 #include <kglobal.h>
 #include <kiconloader.h>
-#include <kdeversion.h>
-#if KDE_IS_VERSION(3,1,90)
 #include <kinputdialog.h>
-#else
-#include <klineeditdlg.h>
-#endif
 
 using Tellico::Kernel;
 Kernel* Kernel::s_self = 0;
 
-Kernel::Kernel(MainWindow* parent) : m_widget(parent), m_commandHistory(parent->actionCollection()), m_commandGroup(0) {
+Kernel::Kernel(MainWindow* parent) : m_widget(parent)
+    , m_commandHistory(parent->actionCollection())
+    , m_commandGroup(0) {
 }
 
 const KURL& Kernel::URL() const {
@@ -71,14 +70,14 @@ QStringList Kernel::valuesByFieldName(const QString& name_) const {
   return Data::Document::self()->collection()->valuesByFieldName(name_);
 }
 
-const QString& Kernel::entryName() const {
-  return Data::Document::self()->collection()->entryName();
-}
-
 int Kernel::collectionType() const {
   return Data::Document::self()->collection()->type();
 }
 
+QString Kernel::collectionTypeName() const {
+  return Data::Document::self()->collection()->typeName();
+}
+
 void Kernel::sorry(const QString& text_, QWidget* widget_/* =0 */) {
   if(text_.isEmpty()) {
     return;
@@ -98,6 +97,7 @@ void Kernel::beginCommandGroup(const QString& name_) {
 void Kernel::endCommandGroup() {
   if(!m_commandGroup) {
     myDebug() << "Kernel::endCommandGroup() - beginCommandGroup() must be called first!" << endl;
+    return;
   }
   if(m_commandGroup->isEmpty()) {
     delete m_commandGroup;
@@ -113,7 +113,7 @@ void Kernel::resetHistory() {
   m_commandHistory.documentSaved();
 }
 
-bool Kernel::addField(Data::Field* field_) {
+bool Kernel::addField(Data::FieldPtr field_) {
   if(!field_) {
     return false;
   }
@@ -123,11 +123,11 @@ bool Kernel::addField(Data::Field* field_) {
   return true;
 }
 
-bool Kernel::modifyField(Data::Field* field_) {
+bool Kernel::modifyField(Data::FieldPtr field_) {
   if(!field_) {
     return false;
   }
-  Data::Field* oldField = Data::Document::self()->collection()->fieldByName(field_->name());
+  Data::FieldPtr oldField = Data::Document::self()->collection()->fieldByName(field_->name());
   if(!oldField) {
     return false;
   }
@@ -138,7 +138,7 @@ bool Kernel::modifyField(Data::Field* field_) {
   return true;
 }
 
-bool Kernel::removeField(Data::Field* field_) {
+bool Kernel::removeField(Data::FieldPtr field_) {
   if(!field_) {
     return false;
   }
@@ -148,18 +148,54 @@ bool Kernel::removeField(Data::Field* field_) {
   return true;
 }
 
-void Kernel::saveEntries(Data::EntryVec oldEntries_, Data::EntryVec newEntries_) {
+void Kernel::addEntries(Data::EntryVec entries_, bool checkFields_) {
+  if(entries_.isEmpty()) {
+    return;
+  }
+
+  KCommand* cmd = new Command::AddEntries(Data::Document::self()->collection(), entries_);
+  if(checkFields_) {
+    beginCommandGroup(cmd->name());
+
+    // this is the same as in Command::UpdateEntries::execute()
+    Data::CollPtr c = Data::Document::self()->collection();
+    Data::FieldVec fields = entries_[0]->collection()->fields();
+
+    QPair<Data::FieldVec, Data::FieldVec> p = mergeFields(c, fields, entries_);
+    Data::FieldVec modifiedFields = p.first;
+    Data::FieldVec addedFields = p.second;
+
+    for(Data::FieldVec::Iterator field = modifiedFields.begin(); field != modifiedFields.end(); ++field) {
+      if(c->hasField(field->name())) {
+        doCommand(new Command::FieldCommand(Command::FieldCommand::FieldModify, c,
+                                            field, c->fieldByName(field->name())));
+      }
+    }
+
+    for(Data::FieldVec::Iterator field = addedFields.begin(); field != addedFields.end(); ++field) {
+      doCommand(new Command::FieldCommand(Command::FieldCommand::FieldAdd, c, field));
+    }
+  }
+  doCommand(cmd);
+  if(checkFields_) {
+    endCommandGroup();
+  }
+}
+
+void Kernel::modifyEntries(Data::EntryVec oldEntries_, Data::EntryVec newEntries_) {
   if(newEntries_.isEmpty()) {
     return;
   }
 
-  KCommand* cmd;
-  if(newEntries_[0]->isOwned()) {
-    cmd = new Command::ModifyEntries(Data::Document::self()->collection(), oldEntries_, newEntries_);
-  } else {
-    cmd = new Command::AddEntries(Data::Document::self()->collection(), newEntries_);
+  doCommand(new Command::ModifyEntries(Data::Document::self()->collection(), oldEntries_, newEntries_));
+}
+
+void Kernel::updateEntry(Data::EntryPtr oldEntry_, Data::EntryPtr newEntry_, bool overWrite_) {
+  if(!newEntry_) {
+    return;
   }
-  doCommand(cmd);
+
+  doCommand(new Command::UpdateEntries(Data::Document::self()->collection(), oldEntry_, newEntry_, overWrite_));
 }
 
 void Kernel::removeEntries(Data::EntryVec entries_) {
@@ -188,7 +224,7 @@ bool Kernel::addLoans(Data::EntryVec entries_) {
   return true;
 }
 
-bool Kernel::modifyLoan(Data::Loan* loan_) {
+bool Kernel::modifyLoan(Data::LoanPtr loan_) {
   if(!loan_) {
     return false;
   }
@@ -215,7 +251,7 @@ bool Kernel::removeLoans(Data::LoanVec loans_) {
   return true;
 }
 
-void Kernel::addFilter(Filter* filter_) {
+void Kernel::addFilter(FilterPtr filter_) {
   if(!filter_) {
     return;
   }
@@ -223,13 +259,16 @@ void Kernel::addFilter(Filter* filter_) {
   doCommand(new Command::FilterCommand(Command::FilterCommand::FilterAdd, filter_));
 }
 
-bool Kernel::modifyFilter(Filter* filter_) {
+bool Kernel::modifyFilter(FilterPtr filter_) {
+  if(!filter_) {
+    return false;
+  }
+
   FilterDialog filterDlg(FilterDialog::ModifyFilter, m_widget);
   // need to create a new filter object
-  Filter* newFilter = new Filter(*filter_);
+  FilterPtr newFilter = new Filter(*filter_);
   filterDlg.setFilter(newFilter);
   if(filterDlg.exec() != QDialog::Accepted) {
-    delete newFilter;
     return false;
   }
 
@@ -237,7 +276,7 @@ bool Kernel::modifyFilter(Filter* filter_) {
   return true;
 }
 
-bool Kernel::removeFilter(Filter* filter_) {
+bool Kernel::removeFilter(FilterPtr filter_) {
   if(!filter_) {
     return false;
   }
@@ -260,19 +299,19 @@ void Kernel::reorderFields(const Data::FieldVec& fields_) {
                                        fields_));
 }
 
-void Kernel::appendCollection(Data::Collection* coll_) {
+void Kernel::appendCollection(Data::CollPtr coll_) {
   doCommand(new Command::CollectionCommand(Command::CollectionCommand::Append,
                                            Data::Document::self()->collection(),
                                            coll_));
 }
 
-void Kernel::mergeCollection(Data::Collection* coll_) {
+void Kernel::mergeCollection(Data::CollPtr coll_) {
   doCommand(new Command::CollectionCommand(Command::CollectionCommand::Merge,
                                            Data::Document::self()->collection(),
                                            coll_));
 }
 
-void Kernel::replaceCollection(Data::Collection* coll_) {
+void Kernel::replaceCollection(Data::CollPtr coll_) {
   doCommand(new Command::CollectionCommand(Command::CollectionCommand::Replace,
                                            Data::Document::self()->collection(),
                                            coll_));
@@ -280,13 +319,8 @@ void Kernel::replaceCollection(Data::Collection* coll_) {
 
 void Kernel::renameCollection() {
   bool ok;
-#if KDE_IS_VERSION(3,1,90)
   QString newTitle = KInputDialog::getText(i18n("Rename Collection"), i18n("New collection name:"),
                                            Data::Document::self()->collection()->title(), &ok, m_widget);
-#else
-  QString newTitle = KLineEditDlg::getText(i18n("Rename Collection"), i18n("New collection name:"),
-                                           Data::Document::self()->collection()->title(), &ok, m_widget);
-#endif
   if(ok) {
     doCommand(new Command::RenameCollection(Data::Document::self()->collection(), newTitle));
   }
@@ -300,3 +334,36 @@ void Kernel::doCommand(KCommand* command_) {
     Data::Document::self()->slotSetModified(true);
   }
 }
+
+QPair<Tellico::Data::FieldVec, Tellico::Data::FieldVec> Kernel::mergeFields(Data::CollPtr coll_,
+                                                                            Data::FieldVec fields_,
+                                                                            Data::EntryVec entries_) {
+  Data::FieldVec modified, created;
+  for(Data::FieldVec::Iterator field = fields_.begin(); field != fields_.end(); ++field) {
+    // don't add a field if it's a default field and not in the current collection
+    if(coll_->hasField(field->name()) || CollectionFactory::isDefaultField(coll_->type(), field->name())) {
+      // special case for choice fields, since we might want to add a value
+      if(field->type() == Data::Field::Choice && coll_->hasField(field->name())) {
+        QStringList a1 = field->allowed();
+        QStringList a2 = coll_->fieldByName(field->name())->allowed();
+        if(a1 != a2) {
+          StringSet a;
+          a.add(a1);
+          a.add(a2);
+          Data::FieldPtr f = new Data::Field(*coll_->fieldByName(field->name()));
+          f->setAllowed(a.toList());
+          modified.append(f);
+        }
+      }
+      continue;
+    }
+    // add field if any values are not empty
+    for(Data::EntryVec::Iterator entry = entries_.begin(); entry != entries_.end(); ++entry) {
+      if(!entry->field(field).isEmpty()) {
+        created.append(new Data::Field(*field));
+        break;
+      }
+    }
+  }
+  return qMakePair(modified, created);
+}
