@@ -1,5 +1,5 @@
 /***************************************************************************
-    copyright            : (C) 2003-2004 by Robby Stephenson
+    copyright            : (C) 2003-2006 by Robby Stephenson
     email                : robby@periapsis.org
  ***************************************************************************/
 
@@ -33,11 +33,22 @@ namespace Tellico {
  * translate to other formats.
  *
  * @author Robby Stephenson
- * @version $Id: xslthandler.h 1077 2005-02-05 20:35:51Z robby $
  */
 class XSLTHandler {
 
 public:
+  class XMLOutputBuffer {
+  public:
+    XMLOutputBuffer();
+    ~XMLOutputBuffer();
+    bool isValid() const { return (m_buf != 0); }
+    xmlOutputBuffer* buffer() const { return m_buf; }
+    QString result() const { return m_res; }
+  private:
+    xmlOutputBuffer* m_buf;
+    QString m_res;
+  };
+
   /**
    * @param xsltFile The XSLT file
    */
@@ -50,7 +61,7 @@ public:
    * @param xsltDoc The XSLT DOM document
    * @param xsltFile The XSLT file, should be a url?
    */
-  XSLTHandler(const QDomDocument& xsltDoc, const QCString& xsltFile);
+  XSLTHandler(const QDomDocument& xsltDoc, const QCString& xsltFile, bool translate=false);
   /**
    */
   ~XSLTHandler();
@@ -62,7 +73,7 @@ public:
    * @param dom The XSLT DOM document
    * @param xsltFile The XSLT file, should be a url?
    */
-  void setXSLTDoc(const QDomDocument& dom, const QCString& xsltFile);
+  void setXSLTDoc(const QDomDocument& dom, const QCString& xsltFile, bool translate=false);
   /**
    * Adds a param
    */
@@ -72,6 +83,7 @@ public:
    */
   void addStringParam(const QCString& name, const QCString& value);
   void removeParam(const QCString& name);
+  const QCString& param(const QCString& name);
   /**
    * Processes text through the XSLT transformation.
    *
@@ -81,6 +93,8 @@ public:
    */
   QString applyStylesheet(const QString& text);
 
+  static QDomDocument& setLocaleEncoding(QDomDocument& dom);
+
 private:
   void init();
   QString process();
